@@ -317,7 +317,7 @@ auth_callback (RestProxyCall *call,
  * oauth_proxy_auth_step_async:
  * @proxy: an #OAuthProxy
  * @function: the function to invoke on the proxy
- * @callback: the callback to invoke when authorisation is complete
+ * @callback: (scope async): the callback to invoke when authorisation is complete
  * @weak_object: the #GObject to weakly reference and tie the lifecycle too
  * @user_data: data to pass to @callback
  * @error_out: a #GError, or %NULL
@@ -426,7 +426,7 @@ oauth_proxy_request_token (OAuthProxy *proxy,
   }
 
   /* TODO: sanity check response */
-  oauth_proxy_call_parse_token_reponse (OAUTH_PROXY_CALL (call));
+  oauth_proxy_call_parse_token_response (OAUTH_PROXY_CALL (call));
 
   g_object_unref (call);
 
@@ -446,7 +446,7 @@ request_token_cb (RestProxyCall *call,
   g_assert (proxy);
 
   if (!error) {
-    oauth_proxy_call_parse_token_reponse (OAUTH_PROXY_CALL (call));
+    oauth_proxy_call_parse_token_response (OAUTH_PROXY_CALL (call));
   }
 
   data->callback (proxy, error, weak_object, data->user_data);
@@ -461,7 +461,7 @@ request_token_cb (RestProxyCall *call,
  * @proxy: an #OAuthProxy
  * @function: the function name to invoke
  * @callback_uri: the callback URI
- * @callback: a #OAuthProxyAuthCallback to invoke on completion
+ * @callback: (scope async): a #OAuthProxyAuthCallback to invoke on completion
  * @weak_object: #GObject to weakly reference and tie the lifecycle of the method call too
  * @user_data: user data to pass to @callback
  * @error: a #GError, or %NULL
@@ -543,7 +543,7 @@ oauth_proxy_access_token (OAuthProxy *proxy,
   }
 
   /* TODO: sanity check response */
-  oauth_proxy_call_parse_token_reponse (OAUTH_PROXY_CALL (call));
+  oauth_proxy_call_parse_token_response (OAUTH_PROXY_CALL (call));
 
   g_object_unref (call);
 
@@ -563,7 +563,7 @@ access_token_cb (RestProxyCall *call,
   g_assert (proxy);
 
   if (!error) {
-    oauth_proxy_call_parse_token_reponse (OAUTH_PROXY_CALL (call));
+    oauth_proxy_call_parse_token_response (OAUTH_PROXY_CALL (call));
   }
 
   data->callback (proxy, error, weak_object, data->user_data);
@@ -578,7 +578,7 @@ access_token_cb (RestProxyCall *call,
  * @proxy: an #OAuthProxy
  * @function: the function name to invoke
  * @verifier: the verifier
- * @callback: a #OAuthProxyAuthCallback to invoke on completion
+ * @callback: (scope async): a #OAuthProxyAuthCallback to invoke on completion
  * @weak_object: #GObject to weakly reference and tie the lifecycle of the method call too
  * @user_data: user data to pass to @callback
  * @error: a #GError, or %NULL
